---
title: <span class="badge object-type-scalar"></span> VoltAmpere
---
# <span class="badge object-type-scalar"></span> VoltAmpere

Energy: Volt-Ampere (VA)

## Definition

```python
# Energy: Volt-Ampere (VA)
VoltAmpere: typing.Literal["voltamp"] = "voltamp"
```
